@@ -2,7 +2,7 @@ package App::Yath::Plugin::Cover;
 use strict;
 use warnings;
 
-our $VERSION = '1.000067';
+our $VERSION = '1.000068';
 
 use Test2::Harness::Util qw/clean_path/;
 use Test2::Harness::Util::JSON qw/encode_json/;
@@ -26,6 +26,11 @@ option_group {prefix => 'cover', category => "Cover Options"} => sub {
         alt => ['cover-dir'],
         type => 'm',
         default => sub { ['lib'] },
+
+        action => sub {
+            my ($prefix, $field, $raw, $norm, $slot, $settings) = @_;
+            push @$$slot => glob($norm);
+        },
     );
 
     option exclude_private => (
